% Copyright (C) 2017, 2018 Rune Kjerrumgaard Jensen,  
% Jesper Kr Larsen, and  Kasper Lindgren Lassen
%
% Permission is hereby granted, free of charge, to any person obtaining
% a copy of this software and associated documentation files (the
% "Software"), to deal in the Software without restriction, including
% without limitation the rights to use, copy, modify, merge, publish,
% distribute, sublicense, and/or sell copies of the Software, and to
% permit persons to whom the Software is furnished to do so, subject to
% the following conditions:
%
% The above copyright notice and this permission notice shall be
% included in all copies or substantial portions of the Software.
%
% THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
% EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
% MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
% NONINFRINGEMENT. IN NO EVENT SHALL AUTHORS BE LIABLE FOR ANY
% CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
% TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
% SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
%
% Except as contained in this notice, the name of the authors shall
% not be used in advertising or otherwise to promote the sale, use or
% other dealings in this Software without prior written authorization
% from the authors.

function J_u = BrunoneFricm(Q, Re, D, j, i, a, dt, dx,g,A)
%% Brunone's unsteady friction model
% Brunone's unsteady friction is calculated for the negative
% characteristics line.
if Re < 2100
    % Vardy shear coefficient for laminar flow                              [-]
    C = 0.00476;
else
    % Vardy shear coefficient for turbulent flow                            [-]
    C = 7.41/(Re^(log10(14.3/...
        Re^0.05)));
end

% Brunone's friction coefficient                                            [-]
k = sqrt(C)/2;

% For j = 2, there is no nodes two time steps, so it is not possible to
% calculate the acceleration of the volumetric flow rate. It is therefore
% set to zero, because two values from steady state would otherwise be
% used, which would result in zero for the acceleration term.
if j == 2
    % Unsteady friction term                                                [m]
    J_u = a*dt*k/(g*A)*(a*sign(Q(i+1,j-1))...
        *abs((Q(i+1,j-1)-Q(i,j-1))/dx));
else
    % Unsteady friction term                                                [m]
    J_u = a*dt*k/(g*A)*((Q(i+1,j-1)-Q(i+1,j-2))/dt + a*sign(Q(i+1,j-1))...
        *abs((Q(i+1,j-1)-Q(i,j-1))/dx));
end
end