% Copyright (C) 2017, 2018 Rune Kjerrumgaard Jensen,  
% Jesper Kr Larsen, and  Kasper Lindgren Lassen
%
% Permission is hereby granted, free of charge, to any person obtaining
% a copy of this software and associated documentation files (the
% "Software"), to deal in the Software without restriction, including
% without limitation the rights to use, copy, modify, merge, publish,
% distribute, sublicense, and/or sell copies of the Software, and to
% permit persons to whom the Software is furnished to do so, subject to
% the following conditions:
%
% The above copyright notice and this permission notice shall be
% included in all copies or substantial portions of the Software.
%
% THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
% EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
% MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
% NONINFRINGEMENT. IN NO EVENT SHALL AUTHORS BE LIABLE FOR ANY
% CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
% TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
% SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
%
% Except as contained in this notice, the name of the authors shall
% not be used in advertising or otherwise to promote the sale, use or
% other dealings in this Software without prior written authorization
% from the authors.

function J_u = CBFricm(dt, j, i, D, rho, viscosity, g,A,a,W,dQ,n_t)
%% Convolution based friction models
% The convolution based friction is calculated for the negative
% characteristics line (the weighting factor W(tau) defines if it is Vardy
% & Brown's unsteady friction model being used or another).
if j > 2
    % Unsteady friction term                                                [m]
    J_u = 16*viscosity*dt*a*sum(dQ(i+1,n_t-j+2:n_t-1).*...
        W(1,1:j-2))/(D^2*rho*A*g);
else
    % Unsteady friction term                                                [m]
    J_u = 0;
end
end