% Copyright (C) 2017, 2018 Rune Kjerrumgaard Jensen,  
% Jesper Kr Larsen, and  Kasper Lindgren Lassen
%
% Permission is hereby granted, free of charge, to any person obtaining
% a copy of this software and associated documentation files (the
% "Software"), to deal in the Software without restriction, including
% without limitation the rights to use, copy, modify, merge, publish,
% distribute, sublicense, and/or sell copies of the Software, and to
% permit persons to whom the Software is furnished to do so, subject to
% the following conditions:
%
% The above copyright notice and this permission notice shall be
% included in all copies or substantial portions of the Software.
%
% THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
% EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
% MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
% NONINFRINGEMENT. IN NO EVENT SHALL AUTHORS BE LIABLE FOR ANY
% CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
% TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
% SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
%
% Except as contained in this notice, the name of the authors shall
% not be used in advertising or otherwise to promote the sale, use or
% other dealings in this Software without prior written authorization
% from the authors.

function C_m = Characteristic_Minus(a, g, A, D, dx, roughness, rho,...
    viscosity, alpha, Q_m, H_m, Q, Re_0, i, j, dt, Friction_Type, Q_0,...
    f_pre, W, dQ, n_t)
%% Calculation of the negative characteristics line.
% In "FrictionTerm", "Charact_Line" indicates whether the friction term is
% for the positive or the negative characteristics line.
Charact_Line = 'Minus';

% Pipe constant                                                             [s/m^2]
B = PipeConst(a, g, A);

% Friction term                                                             [m]
J = FrictionTerm(Friction_Type, D, roughness, rho, Re_0, Q_0, Q_m, Q,...
    viscosity, A, i, j, dx, dt, Charact_Line, g, a, f_pre, W, dQ, n_t);

% Negative characteristics equation                                         [m]
C_m = H_m + Q_m*(-B + dx/(a*A)*sind(alpha)) + J;
end