% Copyright (C) 2017, 2018 Rune Kjerrumgaard Jensen,  
% Jesper Kr Larsen, and  Kasper Lindgren Lassen
%
% Permission is hereby granted, free of charge, to any person obtaining
% a copy of this software and associated documentation files (the
% "Software"), to deal in the Software without restriction, including
% without limitation the rights to use, copy, modify, merge, publish,
% distribute, sublicense, and/or sell copies of the Software, and to
% permit persons to whom the Software is furnished to do so, subject to
% the following conditions:
%
% The above copyright notice and this permission notice shall be
% included in all copies or substantial portions of the Software.
%
% THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
% EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
% MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
% NONINFRINGEMENT. IN NO EVENT SHALL AUTHORS BE LIABLE FOR ANY
% CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
% TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
% SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
%
% Except as contained in this notice, the name of the authors shall
% not be used in advertising or otherwise to promote the sale, use or
% other dealings in this Software without prior written authorization
% from the authors.

function W = WeightFuncVardyBrown(viscosity, dt, D, rho, Re_0,n_t)
%% Vardy and Brown's weighting function
% Dimensionless time step                                                   [-]
dtau = 4*viscosity*dt/(D^2*rho);
% Constant                                                                  [-]
A_star = 1/(2*sqrt(pi));
% Constant                                                                  [-]
Kappa = log10(15.29*Re_0^(-0.0567));
% Constant                                                                  [-]
B_star = Re_0^Kappa/12.86;

for j = 1:n_t-2
    % Dimensionless time [-]
    tau(j) = j*dtau - 0.5*dtau;
    % Weighting function [-]
    W(j) = A_star * exp(-B_star*tau(j))/sqrt(tau(j));
end
end