% Copyright (C) 2017, 2018 Rune Kjerrumgaard Jensen,  
% Jesper Kr Larsen, and  Kasper Lindgren Lassen
%
% Permission is hereby granted, free of charge, to any person obtaining
% a copy of this software and associated documentation files (the
% "Software"), to deal in the Software without restriction, including
% without limitation the rights to use, copy, modify, merge, publish,
% distribute, sublicense, and/or sell copies of the Software, and to
% permit persons to whom the Software is furnished to do so, subject to
% the following conditions:
%
% The above copyright notice and this permission notice shall be
% included in all copies or substantial portions of the Software.
%
% THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
% EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
% MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
% NONINFRINGEMENT. IN NO EVENT SHALL AUTHORS BE LIABLE FOR ANY
% CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
% TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
% SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
%
% Except as contained in this notice, the name of the authors shall
% not be used in advertising or otherwise to promote the sale, use or
% other dealings in this Software without prior written authorization
% from the authors.

function [W] = WeightFuncZielke(viscosity,dt,D,rho,n_t)
%   Zielke weighting function
%   Applicable for laminar flow 
dtau = 4*viscosity*dt/(D^2*rho);              % Dimensionless time step [-]
mj = [0.282095; -1.25; 1.057855; 0.9375; 0.396696;...
    -0.351563];                               % Constants [-]
nj = [26.3744; 70.8493; 135.0198; 218.9216;... 
    322.5544];                                % Constants [-]
for j = 1:n_t-2
    tau(j) = j*dtau - 0.5*dtau;               % Dimensionless time [-]
    if tau <= 0.2
        for k = 1:6
            Wcal(k) = mj(k) * ...
                tau(j)^((k-2)/2);             % Weighting function [-]
        end
    else
        for k = 1:5
            Wcal(k) = exp(-nj(k)*tau(j));     % Weighting function [-]
        end
    end
    W(j) = sum(Wcal);                         % Weighting function [-]
end
end

