%-%-%-%-% MASTER %-%-%-%-%
% Copyright (C) 2017, 2018 Rune Kjerrumgaard Jensen,  
% Jesper Kr Larsen, and  Kasper Lindgren Lassen
%
% Permission is hereby granted, free of charge, to any person obtaining
% a copy of this software and associated documentation files (the
% "Software"), to deal in the Software without restriction, including
% without limitation the rights to use, copy, modify, merge, publish,
% distribute, sublicense, and/or sell copies of the Software, and to
% permit persons to whom the Software is furnished to do so, subject to
% the following conditions:
%
% The above copyright notice and this permission notice shall be
% included in all copies or substantial portions of the Software.
%
% THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
% EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
% MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
% NONINFRINGEMENT. IN NO EVENT SHALL AUTHORS BE LIABLE FOR ANY
% CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
% TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
% SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
%
% Except as contained in this notice, the name of the authors shall
% not be used in advertising or otherwise to promote the sale, use or
% other dealings in this Software without prior written authorization
% from the authors.


clear
clc

%% Starting timer
tic

%% Adding folders to directory
addpath('Functions','Output','Solver','Solver\Boundary',...
    'Solver\InteriorNodes','Solver\SteadyState','Output\Plot','Input')

%% Specify Input File
%Input
%Input_OnePhase_Traudt
%Input_OnePhase_Covas
%Input_OnePhase_Adamkowski
%Input_OnePhase_Soares
%Input_TwoPhase_Soares_DVCM
%Input_TwoPhase_Soares_DGCM
%Input_TwoPhase_Bergant_Low_DVCM
%Input_TwoPhase_Bergant_Low_DGCM
Input_TwoPhase_Bergant_High_DVCM
%Input_TwoPhase_Bergant_High_DGCM

%% Calculating the size and number of the reaches and time steps.
% Travelling time for the pressure wave, from downstream to upstream
t_trav = L/a;
% Time step size                                                            [s]
dt = t_trav/Reaches;
% Maximum time                                                              [s]
t_max = 4*Oscillations*t_trav;
% Reach length (distance between nodes)                                     [m]
dx = a*dt;
% Number of time steps                                                      [-]
n_t = round(t_max/dt + 1);
% Number of nodes                                                           [-]
n = round(L/dx + 1);

%% Calculating the weighting function for unsteady friction
W = 0;
switch Friction_Type
    case 'Unsteady_Friction_Zielke'
        W = WeightFuncZielke(viscosity,dt,D,rho,n_t);
    case 'Unsteady_Friction_VardyBrown'
        W = WeightFuncVardyBrown(viscosity, dt, D, rho, Re_0,n_t);
    case 'Unsteady_Friction_Zarzycki'
        W = WeightFuncZarzycki(viscosity, dt, D, rho, Re_0, n_t);
end

%% Solver
switch Solver
    case '1D_SinglePhase'
        Solver_SinglePhase
    case '1D_TwoPhase_DVCM'
        Solver_DVCM
    case '1D_TwoPhase_DGCM'
        Solver_DGCM
end

%% Displaying and storing the calculation time
toc
% Calculation time                                                          [s]
t_cal = toc;

%% Output
Output
