% Copyright (C) 2017, 2018 Rune Kjerrumgaard Jensen,  
% Jesper Kr Larsen, and  Kasper Lindgren Lassen
%
% Permission is hereby granted, free of charge, to any person obtaining
% a copy of this software and associated documentation files (the
% "Software"), to deal in the Software without restriction, including
% without limitation the rights to use, copy, modify, merge, publish,
% distribute, sublicense, and/or sell copies of the Software, and to
% permit persons to whom the Software is furnished to do so, subject to
% the following conditions:
%
% The above copyright notice and this permission notice shall be
% included in all copies or substantial portions of the Software.
%
% THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
% EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
% MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
% NONINFRINGEMENT. IN NO EVENT SHALL AUTHORS BE LIABLE FOR ANY
% CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
% TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
% SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
%
% Except as contained in this notice, the name of the authors shall
% not be used in advertising or otherwise to promote the sale, use or
% other dealings in this Software without prior written authorization
% from the authors.

%% Output data to text files
% Volumetric flow rate
save('Output\Text_Files\Flow_Rate.txt','Q','-ascii')
save('Output\Mat_Files\Flow_Rate.mat','Q')

% Piezometric head
save('Output\Text_Files\Head.txt','H','-ascii')
save('Output\Mat_Files\Head.mat','H')

% Time
save('Output\Text_Files\t.txt','t','-ascii')
save('Output\Mat_Files\t.mat','t')

% Size of vapour cavities
switch Solver
    case '1D_TwoPhase_DVCM'
        save('Output\Text_Files\Volume_Cavities.txt','V_cav','-ascii')
        save('Output\Mat_Files\Volume_Cavities.mat','V_cav')
    case '1D_TwoPhase_DGCM'
        save('Output\Text_Files\Volume_Gas.txt','V_g','-ascii')
        save('Output\Mat_Files\Volume_Gas.mat','V_g')
end

%% Outputs n figures with two graphs on each.
Plot_Box = questdlg('Do you want to generate the plots? (use the mouse)?','','Yes','No','No');
if strcmp('Yes',Plot_Box) == 1
    % The top graph shows the piezometric head vs time.
    % The bottom graph shows the volumetric flow rate vs time.
    for i = 1:n
        figure(i)
        subplot(2,1,1)
        plot(t,H(i,:))
        title(['Piezometric head vs Time at node ',num2str(i),' (',num2str((n-i)*dx,'% 10.3f'),'m from the valve)'])
        xlabel('Time [s]')
        ylabel('Head [m]')
        axis([0 max(t) min(min(H)) max(max(H))])
        grid on
        subplot(2,1,2)
        plot(t,Q(i,:))
        title(['Volumetric flow rate vs Time at node ',num2str(i),' (',num2str((n-i)*dx,'% 10.3f'),'m from the valve)'])
        xlabel('Time [s]')
        ylabel('Flow rate [m^3/s]')
        axis([0 max(t) min(min(Q)) max(max(Q))])
        grid on
        set(gcf,'PaperPositionMode','auto')
        set(gcf,'units','normalized','outerposition',[0 0 1 1])
        saveas(figure(i),['Output\Plot\Head_and_Flow_Node_',num2str(i),'.png'])
        close
    end
end