% Copyright (C) 2017, 2018 Rune Kjerrumgaard Jensen,  
% Jesper Kr Larsen, and  Kasper Lindgren Lassen
%
% Permission is hereby granted, free of charge, to any person obtaining
% a copy of this software and associated documentation files (the
% "Software"), to deal in the Software without restriction, including
% without limitation the rights to use, copy, modify, merge, publish,
% distribute, sublicense, and/or sell copies of the Software, and to
% permit persons to whom the Software is furnished to do so, subject to
% the following conditions:
%
% The above copyright notice and this permission notice shall be
% included in all copies or substantial portions of the Software.
%
% THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
% EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
% MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
% NONINFRINGEMENT. IN NO EVENT SHALL AUTHORS BE LIABLE FOR ANY
% CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
% TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
% SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
%
% Except as contained in this notice, the name of the authors shall
% not be used in advertising or otherwise to promote the sale, use or
% other dealings in this Software without prior written authorization
% from the authors.

function [Q_u_P, Q_P, H_P, V_g_P] = Reservoir_Upstream_DGCM(a, g, A,...
    rho, D, dx, viscosity, roughness, theta, Q_u_B, H_B, H_r, Q_u, Re_0,...
    i, j, dt, Friction_Type, Q_0, f_pre, W, dQ, n_t, H_0, alpha_0,...
    V_total, z_P, H_v)
%% Boundary conditions for upstream reservoir
% Pipe constant                                                             [s/m^2]
B = PipeConst(a, g, A);

% Negative characteristics equation                                         [m]
C_m = Characteristic_Minus(a, g, A, D, dx, roughness, rho, viscosity,...
    theta, Q_u_B, H_B, Q_u, Re_0, i, j, dt, Friction_Type, Q_0, f_pre,...
    W, dQ, n_t);

% Piezometric head                                                          [m]
H_P = H_r;
% Volumetric flow rate                                                      [m^3/s]
Q_P = (H_P - C_m)/B;
% Volumetric flow rate                                                      [m^3/s]
Q_u_P = Q_P;

% Pressure at steady state                                                  [Pa]
P_0 = rho*g*(H_0 - z_P - H_v);
% Constant                                                                  [m^4]
C_3 = P_0*alpha_0*V_total/(rho*g);
% Gas cavity volume                                                         [m^3]
V_g_P = C_3/(H_P - z_P - H_v);
end