% Copyright (C) 2017, 2018 Rune Kjerrumgaard Jensen,  
% Jesper Kr Larsen, and  Kasper Lindgren Lassen
%
% Permission is hereby granted, free of charge, to any person obtaining
% a copy of this software and associated documentation files (the
% "Software"), to deal in the Software without restriction, including
% without limitation the rights to use, copy, modify, merge, publish,
% distribute, sublicense, and/or sell copies of the Software, and to
% permit persons to whom the Software is furnished to do so, subject to
% the following conditions:
%
% The above copyright notice and this permission notice shall be
% included in all copies or substantial portions of the Software.
%
% THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
% EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
% MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
% NONINFRINGEMENT. IN NO EVENT SHALL AUTHORS BE LIABLE FOR ANY
% CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
% TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
% SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
%
% Except as contained in this notice, the name of the authors shall
% not be used in advertising or otherwise to promote the sale, use or
% other dealings in this Software without prior written authorization
% from the authors.

function [Q_P, H_P] = Valve_Closure(a, g, A, D, dx, roughness, rho,...
    viscosity, t, t_c, m, theta, Q_0, H_0, Q_A, H_A, Q, Re_0, i, j, dt,...
    Friction_Type, f_pre, W, dQ, n_t)
%% Calculating the dimensionless closure time for the valve
if t < t_c
    % Dimensionless valve closure time                                      [-]
    tau_v = 1 - (t/t_c)^m;
else
    % Dimensionless valve closure time                                      [-]
    tau_v = 0;
end

%% Calculating the volumetric flow rate at the valve
% Pipe constant                                                             [s/m^2]
B = PipeConst(a, g, A);

% Positive characteristics equation                                         [m]
C_p = Characteristic_Plus(a, g, A, D, dx, roughness, rho,...
    viscosity, theta, Q_A, H_A, Q, Re_0, i, j, dt,...
    Friction_Type, Q_0, f_pre, W, dQ, n_t);

% Variable                                                                  [m^5/s^2]
C_v = (Q_0*tau_v)^2/(2*H_0);

% Volumetric flow rate                                                      [m^3/s]
Q_P = - B*C_v + sqrt((B*C_v)^2 + 2*C_v*C_p);

%% Calculation of the head
% Piezometric head                                                          [m]
H_P = C_p - B*Q_P;

end