% Copyright (C) 2017, 2018 Rune Kjerrumgaard Jensen,  
% Jesper Kr Larsen, and  Kasper Lindgren Lassen
%
% Permission is hereby granted, free of charge, to any person obtaining
% a copy of this software and associated documentation files (the
% "Software"), to deal in the Software without restriction, including
% without limitation the rights to use, copy, modify, merge, publish,
% distribute, sublicense, and/or sell copies of the Software, and to
% permit persons to whom the Software is furnished to do so, subject to
% the following conditions:
%
% The above copyright notice and this permission notice shall be
% included in all copies or substantial portions of the Software.
%
% THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
% EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
% MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
% NONINFRINGEMENT. IN NO EVENT SHALL AUTHORS BE LIABLE FOR ANY
% CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
% TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
% SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
%
% Except as contained in this notice, the name of the authors shall
% not be used in advertising or otherwise to promote the sale, use or
% other dealings in this Software without prior written authorization
% from the authors.

%% Initialize matrices to reduce calculation time
% Volumetric flow rate                                                      [m^3/s]
Q(1:n,1:n_t) = 0;
% Piezometric head                                                          [m]
H(1:n,1:n_t) = 0;
% Time                                                                      [s]
t(1:n_t) = 0;
% Height from datum                                                         [m]
z(1:n) = 0;
% Volumetric flow rate acceleration                                         [m^3/s^2]
dQ(n,n_t-2) = 0;

%% Calculating the offset of each node from the datum (reference height)
% i indicate node number                                                    [-]
for i = 1:n
    % Height from datum                                                     [m]
    z(i) = (i-1)*dx*sind(theta);
end

%% Steady State
[Q, H] = SteadyState(Q_0, H_r, rho, D, viscosity, a, A, roughness, g,...
    dx, Q, H, n, theta, Friction_Type, f_pre);

%% Transient flow
% j indicate time step number                                               [-]
for j = 2:n_t
    % Time                                                                  [s]
    t(j) = t(j-1) + dt;
    
    %% Interior Nodes
    for i = 2:n-1
        [Q(i,j), H(i,j)] = InteriorNodes_SinglePhase(a, g, A, rho, D,...
            viscosity, roughness, dx, theta, Q(i-1,j-1), H(i-1,j-1),...
            Q(i+1,j-1), H(i+1,j-1), Q, Re_0, i, j, dt, Friction_Type,...
            Q_0, f_pre, W, dQ, n_t);
    end
    
    %% Upstream Boundary
    switch Upstream_boundary
        case 'Reservoir'
            [Q(1,j), H(1,j)] = Reservoir_Upstream(a, g, A, rho, D, dx,...
                viscosity, roughness, theta, Q(2,j-1), H(2,j-1), H_r,....
                Q, Re_0, i, j, dt, Friction_Type, Q_0, f_pre, W, dQ, n_t);
    end
    
    %% Downstream Boundary
    switch Downstream_boundary
        case 'Valve_Instantaneous_Closure'
            [Q(n,j), H(n,j)] = Valve_Closure(a, g, A, D, dx, roughness,...
                rho, viscosity, t(j), t_c, m, theta, Q(n,1), H(n,1),...
                Q(n-1,j-1), H(n-1,j-1), Q, Re_0, i, j, dt,...
                Friction_Type, f_pre, W, dQ, n_t);
        case 'Valve_Transient_Closure'
            [Q(n,j), H(n,j)] = Valve_Closure(a, g, A, D, dx, roughness,...
                rho, viscosity, t(j), t_c, m, theta, Q(n,1), H(n,1),...
                Q(n-1,j-1), H(n-1,j-1), Q, Re_0, i, j, dt,...
                Friction_Type, f_pre, W, dQ, n_t);
    end
    
    %% Calculating the change in volumetric flow rate for unsteady friction
    switch Friction_Type
        case 'Unsteady_Friction_Zielke'
            if j<n_t
                dQ(:,n_t-j+1) = Q(:,j)-Q(:,j-1);
            end
        case 'Unsteady_Friction_VardyBrown'
            if j<n_t
                dQ(:,n_t-j+1) = Q(:,j)-Q(:,j-1);
            end
        case 'Unsteady_Friction_Zarzycki'
            if j<n_t
                dQ(:,n_t-j+1) = Q(:,j)-Q(:,j-1);
            end
    end
end
