% Copyright (C) 2017, 2018 Rune Kjerrumgaard Jensen,  
% Jesper Kr Larsen, and  Kasper Lindgren Lassen
%
% Permission is hereby granted, free of charge, to any person obtaining
% a copy of this software and associated documentation files (the
% "Software"), to deal in the Software without restriction, including
% without limitation the rights to use, copy, modify, merge, publish,
% distribute, sublicense, and/or sell copies of the Software, and to
% permit persons to whom the Software is furnished to do so, subject to
% the following conditions:
%
% The above copyright notice and this permission notice shall be
% included in all copies or substantial portions of the Software.
%
% THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
% EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
% MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
% NONINFRINGEMENT. IN NO EVENT SHALL AUTHORS BE LIABLE FOR ANY
% CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
% TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
% SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
%
% Except as contained in this notice, the name of the authors shall
% not be used in advertising or otherwise to promote the sale, use or
% other dealings in this Software without prior written authorization
% from the authors.

function [Q, H, V_g] = SteadyState_DGCM(Q_0, H_r, rho, D, viscosity, a,...
    A, roughness, g, dx, Q, H, n, theta, Friction_Type, f_pre, alpha_0,...
    V_total, V_g, z_P, H_v)
%% Steady State Solver
% Volumetric flow rate                                                      [m^3/s]
Q(:,1) = Q_0;
% Piezometric head at reservoir                                             [m]
H(1,:) = H_r;

% R is a resistance coefficient, which describes the friction at steady
% state where unsteady friction is zero.
switch Friction_Type
    case 'Prescribed_Steady_State_Friction'
        % Resistance coefficient                                            [s^2/m^5]
        R = f_pre*dx/(2*g*D*A^2);
    otherwise
        % Resistance coefficient                                            [s^2/m^5]
        R = ResistanceCoeff(g, D, A, dx, roughness, rho, Q_0, viscosity);
end

for i = 2:n
    % Piezometric head, disregarding friction                               [m]
    H_0 = H(i-1,1) - dx * sind(theta);
    % Piezometric head                                                      [m]
    H(i,1) = H_0 - R*Q_0*abs(Q_0) + dx/(a*A)*sind(theta)*Q_0;
end

for i = 1:n
    % Gas cavity volume                                                     [m^3]
    V_g(i,1) = alpha_0*V_total(i,1);
end

end